---
hide:
  - navigation
---

<style>
.md-content .md-typeset h1 {
  display: none;
}

.readme {
  display: none!important;
}
</style>

<div style="display: flex; align-items: center; justify-content: center;">
  <svg width="6em" height="6em" viewBox="0 0 24 24">
      <path fill = "currentColor" d = "m12 6.7l1.45 3.85L17.3 12l-3.85 1.45L12 17.3l-1.45-3.85L6.7 12l3.85-1.45zM12 1L9 9l-8 3l8 3l3 8l3-8l8-3l-8-3z" />
  </svg>
  <span style="margin-left: 10px; font-size: 4em;">cyhole</span>
</div>

--8<-- "README.md"
